###################################################
# R code for "Big Data: New Tricks for Econometrics
# Journal of Economic Perspectives 28(2), 3-28            
# http://pubs.aeaweb.org/doi/pdfplus/10.1257/jep.28.2.3
# Hal R. Varian
###################################################

# load libraries and data
library(party)
library(Ecdat)
data(Hdma)
# fix annoying spelling error
names(Hdma)[11] <- "condo"

# for reproducibility
set.seed(1234)

####################################
# all complete cases, all predictors
####################################

all <- Hdma[complete.cases(Hdma),]
all.fit <- ctree(deny ~ .,data=all)
all.pred <- predict(all.fit)
all.conf <- table(all$deny,all.pred)
all.conf
all.error <- all.conf[2,1]+all.conf[1,2]
all.error

#######################################
# no black predictor
#######################################

noblack <- all[,-12]
noblack.fit <- ctree(noblack$deny ~ .,data=noblack)
noblack.pred <- predict(noblack.fit)

# compare these predictions to the "all predictor" predictions
all.equal(all.pred,noblack.pred)

####################################
# remove predictors one-by-one and check error count
####################################

for (t in 1:12) {
drop1 <- all[,-t]
drop1.fit <- ctree(deny ~ .,data=drop1)
drop1.pred <- predict(drop1.fit)
drop1.conf <- table(drop1$deny,drop1.pred)
error <- (drop1.conf[2,1]+drop1.conf[1,2])
print(c(names(all)[t],format((error-all.error),digits=4)))
}

#######################################
# compare to logit
#######################################
logit.fit <- glm(deny ~ .,data=all,family="binomial")
logit.temp <- predict(logit.fit,type="response")
logit.pred <- logit.temp > .5
logit.conf <- table(all$deny,logit.pred)
logit.conf
logit.error <- logit.conf[1,2]+logit.conf[2,1]
logit.error
all.error
summary(logit.fit)

#######################################
# compare to random forest
######################################
library(randomForest)
set.seed(1234)
rf.fit <- randomForest(deny ~ .,data=all,importance=T)
rf.pred <- predict(rf.fit,type="class")
rf.conf <- table(all$deny,rf.pred)
rf.conf
error <- rf.conf[1,2]+rf.conf[2,1]
error
imp <- importance(rf.fit)
rev(sort(imp[,3]))

# importance plot
varImpPlot(rf.fit)
